<?php
if (!isset($urnreg_path)) {
	require_once("../config.php");
}
require_once($siledap_path."/LdapManager.php");
require_once($siledap_path."/LdapEntry.php");
require_once($siledap_path."/LdapAttribute.php");

function sortSubUrns($elem1,$elem2) {
	$val1=explode(":",$elem1->getSingleAttribute("urnRegValue"));
	$val2=explode(":",$elem2->getSingleAttribute("urnRegValue"));
	return count($val1)>count($val2);
}

function getURNEntry($lm,$urnvalue) {
	GLOBAL $URN_LDAP_BASE;

	$filter="(urnRegValue=".$urnvalue.")";
	$entries=$lm->search($URN_LDAP_BASE,$filter);
	if (count($entries)==1) {
		$urn=$entries[0];
		return $urn;
	}
	return "";
}

function echoURNDescription($urn) {
	$xml = new SimpleXMLElement("<urn></urn>");
	$xml->addAttribute("value",$urn->getSingleAttribute("urnRegValue"));
	$descs = $xml->addChild("descriptions");
	foreach ($urn->getAttribute("urnRegValueDescription")->getArrayValues() as $descattr) {
		$desc = $descs->addChild("description");
		$desc->addAttribute("value",$descattr['value']);
	}
	if ($urn->hasAttribute("urnRegValuePresentation")) {
		$pres = $xml->addChild("presentations");
		$attr=$urn->getAttribute("urnRegValuePresentation");
		foreach ($attr->getArrayValues() as $repattr) {
			$pre = $pres->addChild("presentation");
			$pre->addAttribute("value",$repattr['value']);
			if (array_key_exists("lang",$repattr)) {
				$pre->addAttribute("lang",$repattr['lang']);
			}
		}
	}
	$objs=$urn->getObjectClassList()->getValues();
	if (in_array("urnRegContactPerson",$objs)) {
		$cp = $xml->addChild("contactPerson");
		$gn = $cp->addChild("givenName");
		$gn->addAttribute("value",$urn->getSingleAttribute("givenName"));
		$sn1 = $cp->addChild("schacSn1");
		$sn1->addAttribute("value",$urn->getSingleAttribute("schacSn1"));
		$sn2 = $cp->addChild("schacSn2");
		$sn2->addAttribute("value",$urn->getSingleAttribute("schacSn2"));
		$cn = $cp->addChild("cn");
		$cn->addAttribute("value",$urn->getSingleAttribute("cn"));
		$mail = $cp->addChild("mail");
		$mail->addAttribute("value",$urn->getSingleAttribute("mail"));
		$pa = $cp->addChild("postalAddress");
		$pa->addAttribute("value",$urn->getSingleAttribute("postalAddress"));
		$tn = $cp->addChild("phone");
		$tn->addAttribute("value",$urn->getSingleAttribute("telephoneNumber"));
	}
	
	$res = explode("\n", preg_replace('/>\s*</', ">\n<", $xml->asXML()));
	array_shift($res);
	return implode("\n",$res);
}

function echoURNDelegation($urn) {
	$xml = new SimpleXMLElement("<urn></urn>");
	$xml->addAttribute("value",$urn->getSingleAttribute("urnRegValue"));
	$xml->addAttribute("owner",$urn->getSingleAttribute("urnRegOwner"));
	$xml->addAttribute("type","delegated");
	$httpsuri = $xml->addChild("httpsuri");
	$httpsuri->addAttribute("value",$urn->getSingleAttribute("urnRegRegistrarURI"));
	$policyuri = $xml->addChild("policyuri");
	$policyuri->addAttribute("value",$urn->getSingleAttribute("urnRegPolicyURI"));
	$wsuri = $xml->addChild("wsuri");
	$wsuri->addAttribute("value",$urn->getSingleAttribute("urnRegHttpsURI"));
	if ($urn->hasAttribute("urnRegLdapURI")) {
		$ldapuri = $xml->addChild("ldapuri");
		$ldapuri->addAttribute("value",$urn->getSingleAttribute("urnRegLdapURI"));
	}
	$objs=$urn->getObjectClassList()->getValues();
	if (in_array("urnRegContactPerson",$objs)) {
		$cp = $xml->addChild("contactPerson");
		$gn = $cp->addChild("givenName");
		$gn->addAttribute("value",$urn->getSingleAttribute("givenName"));
		$sn1 = $cp->addChild("schacSn1");
		$sn1->addAttribute("value",$urn->getSingleAttribute("schacSn1"));
		$sn2 = $cp->addChild("schacSn2");
		$sn2->addAttribute("value",$urn->getSingleAttribute("schacSn2"));
		$cn = $cp->addChild("cn");
		$cn->addAttribute("value",$urn->getSingleAttribute("cn"));
		$mail = $cp->addChild("mail");
		$mail->addAttribute("value",$urn->getSingleAttribute("mail"));
		$pa = $cp->addChild("postalAddress");
		$pa->addAttribute("value",$urn->getSingleAttribute("postalAddress"));
		$tn = $cp->addChild("phone");
		$tn->addAttribute("value",$urn->getSingleAttribute("telephoneNumber"));
	}
	
	$res = explode("\n", preg_replace('/>\s*</', ">\n<", $xml->asXML()));
	array_shift($res);
	return implode("\n",$res);
}

function getDelegatedURN($urnvalue,$wsEP) {
	$params="?format=machine&urn=".rawurlencode($urnvalue);
	
	$content='';
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $wsEP."/search/".$params);
	curl_setopt($ch, CURLOPT_HEADER, 0); 
	curl_setopt($ch, CURLOPT_POST, 1);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $content);
	ob_start();
	curl_exec ($ch);
	curl_close ($ch);
	$res = ob_get_contents();
	ob_end_clean();

	$xml=new SimpleXMLElement($res);
	if (strcmp($xml->urn['value'],$urnvalue)==0) {
		$xml->urn->addAttribute("delegated",$wsEP);
		return $xml->urn->asXML();
	}
	
    return "";
}

?>